import pandas #import module pandas
from ptstaycool.core.Hasil import Hasil #import file Hasil.py

#class main
class Main:

    #function menghitung lembur
    def lembur(self, jam_kerja):
        self.total_fix = 0
        if jam_kerja >= 240:
            self.total = jam_kerja - 240
            self.total_fix = self.total * 2500
            self.jumlah_jam_kerja.append(jam_kerja)
            self.list_honor_lembur.append(self.total_fix)
        else :
            self.jumlah_jam_kerja.append(jam_kerja)
            self.list_honor_lembur.append(0)
        return 0
    #end lembur

    #function menghitung tunjangan jabatan
    def tunjangan_jabatan(self, golongan):
        tunjangan = 0
        if golongan == 1:
            tunjangan = 5/100
        elif golongan == 2:
            tunjangan = 10/100
        elif golongan == 3:
            tunjangan = 15/100
        else:
            tunjangan = 5/100
        self.total_tunjangan = self.gaji_tetap * (tunjangan)
        return self.list_tunjangan.append(self.total_tunjangan)
    #end tunjangan

    #funciton menentukan pendidikan
    def pendidikan(self, pddkn):
        sekolah = 'SMU'
        if pddkn == 1:
            sekolah = 'SMU'
        elif pddkn == 2:
            sekolah = 'D3'
        elif pddkn == 3:
            sekolah = 'S1'
        return self.list_pendidikan.append(sekolah)
    #end pendidikan

    #function menghitung pajak
    def pajak(self):
        self.total_pajak = self.gaji_tetap * (5/100)
        self.total_pajak_fix = self.gaji_tetap - self.total_pajak
        return self.list_pajak.append('5%')
    #end pajak

    #function menghitung total gaji keluar
    def total_gaji_keluar(self):
        gaji = self.total_pajak_fix + (self.total_fix) + self.total_tunjangan
        self.total_gaji_yang_dikeluarkan.append(gaji)
    #end total gaji keluar


    def mulaii(self, argv):
        for i in range(argv):
            try :
                print('karyawan ke - {}'.format(i+1))
                #input nama karyawan
                nama = input('Nama Karyawan : ')
                self.list_nama.append(nama)
                #end input nama karyawan

                #input golongan
                golongan = int(input('Golongan(1/2/3) : '))
                    
                self.list_golongan.append(golongan)
                self.tunjangan_jabatan(golongan)
                #end input golongan
                #input pendidikan
                pddkn = int(input('Pendidikan (1=SMU/2=D3/3=S1) :'))
                self.pendidikan(pddkn)
                #end input pendidikan

                #input jam kerja
                jam_kerja = int(input('Jumlah Jam Kerja : '))
                self.lembur(jam_kerja)
                #end input jam kerja

                self.list_gaji.append(self.gaji_tetap)

                self.pajak()
                self.total_gaji_keluar()
            except ValueError:
                print('Ups ada kesalahan')
                break
            except KeyboardInterrupt:
                print('\nAnda memaksa untuk keluar, data belum di save')
                break
            
            
        #dictionary staycool
        staycool = {
            'nama_karyawan' : self.list_nama,
            'jabatan' : self.list_golongan,
            'tunjangan' : self.list_tunjangan,
            'pendidikan' : self.list_pendidikan,
            # 'jam_kerja' : self.jumlah_jam_kerja,
            'honor_lembur' : self.list_honor_lembur,
            'pajak' : self.list_pajak,
            'pendapatan_bersih' : self.list_gaji,
            'total_gaji_yang_keluar' : self.total_gaji_yang_dikeluarkan
        }
        #output pandas dataframe
        try: #jika value dalam list komplit
            pd = pandas.DataFrame(staycool)
            print(pd)
        except: #jika value dalam list tidak komplit
            pd = pandas.DataFrame.from_dict(staycool, orient='index')
            print(pd)


        #menentukan file di save atau tidak dalam bentuk .txt
        saveornot = input('Apakah anda ingin penyimpan file? [Y/n] : ')

        if saveornot == 'Y' or saveornot == 'y' :
            namafolder = input('Nama Folder : ')
            Hasil(namafolder, argv, staycool)   
            print('Data disimpan di folder Documents/Hkk_output/{}'.format(namafolder))
            print('Terima kasih sudah menggunakan program kami!')
        else :
            print('Terima kasih sudah menggunakan program kami!')
            exit()

    #function __init__
    def __init__(self,argv=None):
        
        self.gaji_tetap = 2500000
        self.list_gaji = []
        self.list_nama = []
        self.list_golongan = []
        self.list_pendidikan = []
        self.jumlah_jam_kerja = []
        self.list_tunjangan = []
        self.list_honor_lembur = []
        self.list_pajak = []
        self.total_gaji_yang_dikeluarkan = []
        self.jumlah_karyawan = 0
        print('\n')
        
        if argv is None :
            self.jumlah_karyawan = int(input('Masukan Jumlah Karyawan : '))
            if self.jumlah_karyawan == '':
                print('Masukan Value dalam bentuk angka!')
            self.mulaii(self.jumlah_karyawan)
        else:
            print('Jumlah Karyawan : {}'.format(argv))
            self.mulaii(argv)

    #end __init__


try : 
    from ptstaycool.core.Main import Main
except ModuleNotFoundError:
    import os
    print('installing requirements.txt')
    os.system('pip install -r requirements.txt || pip3 install -r requirements.txt') #install module yang diperlukan
    from ptstaycool.core.Main import Main
    
import os
from time import sleep
import sys

desktop = os.path.join(os.path.expanduser('~/Documents/'))+'Hkk_output/'

try :
    os.mkdir(desktop)
except FileExistsError:
    pass

def help():
    print("Usage :")
    print("python start.py [command]\n")
    print("Command :")
    for s in range(len(tostart)):
        print(tostart[s], end =', ')
    print(' | Memulai program')
    for a in range(len(toanggota)):
        print(toanggota[a], end =', ')
    print(' | Melihat anggota kelompok')
    for l in range(len(tolangsung)):
        print(tolangsung[l], end =', ')
    print('[jumlah karyawan] | Menjalankan program')


def mulai():
    #printout
    print('Program Hitung Honor Karyawan Kontrak\nPT. STAY COOL')
    input('Press Enter to start')
    os.system('cls||clear') #clear terminal
    #printout pake animasi
    kata1 = "-------------------Program Hitung Honor Karyawan Kontrak-------------------\n"
    kata2 = "-------------------------------PT. STAY COOL-------------------------------\n"
    for char in kata1:
        sleep(0.01)
        sys.stdout.write(char)
        sys.stdout.flush()
    for char in kata2:
        sleep(0.01)
        sys.stdout.write(char)
        sys.stdout.flush()
    #jalankan program
    Main()

#variasi
tostart = ('start', 'mulai', 'run', '-r', '-m', '-s')
toanggota = ('anggota', 'credit', '-a', '-c')
toclass = ('Main')
tolangsung = ('karyawan', '-k')
tohelp = ('h', 'help', '-h')

if len(sys.argv) > 1:

    if sys.argv[1] in toclass:
        Main()
    elif sys.argv[1] in tostart:
        try:
            mulai()
        except KeyboardInterrupt:
            print('\nSee you!!')
            sys.exit()
        except IndexError :
            print('Completed but ada yang salah')
        except ValueError :
            print('Harus pake Integer')
    elif sys.argv[1] in toanggota :
        print('\n')
        print('Muhamad Dafa Prasetya')
        print('Devi Alvandi')
        print('Dimas Ajie')
        print('Chairil Fajri')
        print('Arie Sutiawan')
        print('\n')
    elif sys.argv[1] in tolangsung:
        try :
            Main(int(sys.argv[2]))
        except IndexError:
            print('Tidak komplit')
        except ValueError :
            print('Masukan value dalam bentuk angka!')
    elif sys.argv[1] in tohelp :
        print('--------------Program Hitung Honor Karyawan Kontrak--------------')
        print('--------------------------PT. Stay Cool--------------------------\n')
        help()

    else:
        for i in range(len(sys.argv[1:])):
            print(sys.argv[i+1],end=' ')
        print('\n')

else :
    help()

